Installation
============


The project was developed using Python 3.10. It's not recommended to use oldered versions of Python as dataclass and type hints are used.
To install packages required to run the project you can use either pip or conda.

1. Install packages using pip: `$ pip install -r requirements.txt`

2. Install packages using conda: `$ conda env create -f environment.yml` -> `$ conda activate extractor`

======
Docker
======
While it's possible to run the project without Docker it's recommended to use it as it will make the process of running the project much easier.
Please install docker and docker-compose before running the project.

